@@ -1,5 +1,5 @@
 // the Tracer trait
-pub trait Tracer {
+pub trait Tracer: Send + Sync {
     fn name(&self) -> &str;
     fn child(&self, child_name: &str) -> Box<dyn Tracer>;
 
@@ -8,6 +8,4 @@ pub trait Tracer {
     fn debug(&self, message: &str) -> &dyn Tracer;
     fn warn(&self, message: &str) -> &dyn Tracer;
     fn error(&self, message: &str) -> &dyn Tracer;
-
-    // fn as_silent(self, is_silent: bool) -> Self;
 }
